package au.id.mcauliffe.obscurer;

/* For license, see license.txt */

import java.util.Map;
import java.util.HashMap;


/**
 * Defines methods available for obscuring strings.
 */
public final class ObscuringMethod
{
    /** A method of obscuring, using a MD5 hash algorithm */
    public static final ObscuringMethod MD5_HASH 
            = new ObscuringMethod("MD5", Md5Algorithm.class);
            
    /** A method of obscuring, using a SHA hash algorithm */
    public static final ObscuringMethod SHA_HASH 
            = new ObscuringMethod("SHA", ShaAlgorithm.class);
            
    private static Map methods = new HashMap();
    
    static
    {
        methods.put(MD5_HASH.name, MD5_HASH);
        methods.put(SHA_HASH.name, SHA_HASH);
    }
    
    /** Returns the method corresponding to the given name, null if one
     *  does not exist.
     *  @param name the name of the algorithm to return.
     */
    public static ObscuringMethod getByName(String name)
    {
        return (ObscuringMethod) methods.get(name);
    }
    
    
    /** The name of this obscuring method, may be used to identify to a human
     *  reader the method used, but should not be relied apon to remain
     *  the same.
     */
    public final String name;
    public final Class algorithmClass;
    
    private ObscuringMethod(String name, Class algorithmClass)
    {
        this.name = name;
        this.algorithmClass = algorithmClass;
    }
    
    public String toString()
    {
        return name+" implemented by class "+algorithmClass.getName();
    }
}
